==> eckit_1.4.7.orig.tar.xz: eckit-1.4.7/src/eckit/linalg/LinearAlgebraViennaCL.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation
 * nor does it submit to any jurisdiction.
 */

/// @file   LinearAlgebraViennaCL.h
/// @author Florian Rathgeber
/// @date   July 2015

#ifndef eckit_la_LinearAlgebraViennaCL_h
#define eckit_la_LinearAlgebraViennaCL_h

#include "eckit/eckit.h"

#ifdef ECKIT_HAVE_VIENNACL

#include "eckit/linalg/LinearAlgebra.h"

namespace eckit {
namespace linalg {

//-----------------------------------------------------------------------------

class LinearAlgebraViennaCL : public LinearAlgebra {

public:
    LinearAlgebraViennaCL();

private:

    // Overridden methods

    virtual Scalar dot(const Vector&, const Vector&) const;
    virtual void gemv(const Matrix&, const Vector&, Vector&) const;
    virtual void gemm(const Matrix&, const Matrix&, Matrix&) const;
    virtual void spmv(const SparseMatrix&, const Vector&, Vector&) const;
    virtual void spmm(const SparseMatrix&, const Matrix&, Matrix&) const;
    virtual void dsptd(const Vector&, const SparseMatrix&, const Vector&, SparseMatrix&) const;

    virtual void print(std::ostream&) const;
};

//-----------------------------------------------------------------------------

}  // namespace linalg
} // namespace eckit

#endif  // ECKIT_HAVE_VIENNACL

#endif

==> eckit_1.15.4.orig.tar.xz: eckit-1.15.4/src/eckit/linalg/LinearAlgebraViennaCL.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation
 * nor does it submit to any jurisdiction.
 */

/// @file   LinearAlgebraViennaCL.h
/// @author Florian Rathgeber
/// @date   July 2015

#ifndef eckit_la_LinearAlgebraViennaCL_h
#define eckit_la_LinearAlgebraViennaCL_h

#include "eckit/eckit.h"

#ifdef eckit_HAVE_VIENNACL

#include "eckit/linalg/LinearAlgebra.h"

namespace eckit {
namespace linalg {

//-----------------------------------------------------------------------------

class LinearAlgebraViennaCL : public LinearAlgebra {

public:
    LinearAlgebraViennaCL();

private:
    // Overridden methods

    virtual Scalar dot(const Vector&, const Vector&) const;
    virtual void gemv(const Matrix&, const Vector&, Vector&) const;
    virtual void gemm(const Matrix&, const Matrix&, Matrix&) const;
    virtual void spmv(const SparseMatrix&, const Vector&, Vector&) const;
    virtual void spmm(const SparseMatrix&, const Matrix&, Matrix&) const;
    virtual void dsptd(const Vector&, const SparseMatrix&, const Vector&, SparseMatrix&) const;

    virtual void print(std::ostream&) const override;
};

//-----------------------------------------------------------------------------

}  // namespace linalg
}  // namespace eckit

#endif  // eckit_HAVE_VIENNACL

#endif
